SampleResponse

Struct SampleResponse 

pub struct SampleResponse<R, E> {
    pub response: Option<(Uri, R)>,
    pub errors: Vec<(Uri, E)>,
}
Response to a sample query.

Fields

response: Option<(Uri, R)>

Paired Uri and response.

errors: Vec<(Uri, E)>

The errors paired with the Uri of the keyserver they originated at.

Implementations

Source

impl<R, E> SampleResponse<R, E>
where R: Debug, E: Debug,

pub fn select<F>( responses: Vec<(Uri, Result<R, E>)>, selector: F, ) -> SampleResponse<R, E>
where F: FnOnce(Vec<(Uri, R)>) -> Option<(Uri, R)>,

Create a sample response from a list of results.